"lmom.test.glo" <-
function(data) {
   lmom <- lmom.ub(data)
   para <- parglo(lmom)
   cat("GENERALIZED LOGISTIC DISTRIBUTION PARAMETERS\n")
   str(para)
   lmompara <- lmomglo(para)
   Q50 <- quaglo(0.5,para)
   cat(c("Computed median=",Q50,"\n"),sep="")
   P50 <- cdfglo(Q50,para)
   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
   lmom.diff(lmompara,lmom)
}

